@@ -2,14 +2,12 @@
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>", message = FALSE, warning = FALSE)
 
 ## ---- message=FALSE------------------------------------------------------
-library(pubh, warn.conflicts = FALSE)
-library(car, warn.conflicts = FALSE)
-library(descr, warn.conflicts = FALSE)
 library(effects, warn.conflicts = FALSE)
+library(kableExtra, warn.conflicts = FALSE)
+library(knitr, warn.conflicts = FALSE)
 library(multcomp, warn.conflicts = FALSE)
-library(pander, warn.conflicts = FALSE)
-
-set.alignment("right", row.names = "left", permanent = TRUE)
+library(papeR, warn.conflicts = FALSE)
+library(pubh, warn.conflicts = FALSE)
 
 ## ---- message=FALSE------------------------------------------------------
 data(birthwt)
@@ -18,40 +16,42 @@ birthwt$race <- factor(birthwt$race > 1, labels=c("White", "Non-white"))
 model_norm <- glm(bwt ~ smoke + race, data = birthwt)
 
 ## ------------------------------------------------------------------------
-pander(Anova(model_norm))
+Anova(model_norm)
 
 ## ------------------------------------------------------------------------
-pander(summary(model_norm))
+summary(model_norm)
 
 ## ------------------------------------------------------------------------
 glm_coef(model_norm)
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_norm, labels=c("Constant", "Smoker - Non-smoker", "Non-white - White"),
-                se.rob = FALSE), split.table=Inf, caption="Table of coeffients using naive 
-       standard errors.")
+kable(glm_coef(model_norm, labels = c("Constant", "Smoker - Non-smoker", 
+                                      "Non-white - White"), se.rob = FALSE),
+      caption = "Table of coeffients using naive standard errors.")
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_norm, labels=c("Constant", "Smoker - Non-smoker", "Non-white - White")),
-       split.table = Inf, caption="Table of coeffients using robust standard errors.")
+kable(glm_coef(model_norm, labels = c("Constant", "Smoker - Non-smoker", 
+                                      "Non-white - White")),
+       caption = "Table of coeffients using robust standard errors.")
 
 ## ------------------------------------------------------------------------
 plot(Effect(c("smoke", "race"), model_norm), multiline = TRUE, main = NULL, 
-     ylab = "Birth weight (g)", xlab = "Smoking status", symbols = list(pch=16),
-     confint = list(style="auto"), aspect = 3/4, lines = list(col=c(2,4), lwd=1.5))
+     ylab = "Birth weight (g)", xlab = "Smoking status", symbols = list(pch = 16),
+     confint = list(style = "auto"), aspect = 3/4, 
+     lines = list(col = c(2, 4), lwd = 1.5))
 
 ## ------------------------------------------------------------------------
 data(diet, package = "Epi")
 model_binom <- glm(chd ~ fibre, data = diet, family = binomial)
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_binom, labels = c("Constant", "Fibre intake (g/day)")), split.table = Inf,
+kable(glm_coef(model_binom, labels = c("Constant", "Fibre intake (g/day)")), 
        caption = "Parameter estimates from logistic regression.")
 
 ## ------------------------------------------------------------------------
 plot(Effect("fibre", model_binom), type = "response", rug = FALSE, aspect = 3/4,
-       ylab = "P (CHD)", xlab = "Fibre (g/day)", lwd = 2, confint = list(style="none"),
-     main = NULL)
+       ylab = "P (CHD)", xlab = "Fibre (g/day)", lwd = 2, 
+     confint = list(style = "none"), main = NULL)
 
 ## ------------------------------------------------------------------------
 data(bdendo, package = "Epi")
@@ -63,9 +63,9 @@ model_clogit <- clogit(d ~ est * gall + strata(set), data = bdendo)
 glm_coef(model_clogit)
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_clogit, labels = c("Oestrogen/No oestrogen", "GBD/No GBD", 
+kable(glm_coef(model_clogit, labels = c("Oestrogen/No oestrogen", "GBD/No GBD", 
                                          "Oestrogen:GBD Interaction")), 
-       split.table = Inf, caption = "Parameter estimates from conditional logistic regression.")
+       caption = "Parameter estimates from conditional logistic regression.")
 
 ## ------------------------------------------------------------------------
 bdendo_grid <- with(bdendo, expand.grid(
@@ -75,12 +75,15 @@ bdendo_grid <- with(bdendo, expand.grid(
 ))
 
 ## ------------------------------------------------------------------------
-bdendo_grid$pred <- inv_logit(predict(model_clogit, bdendo_grid, type = "lp"))
+bdendo_pred <- predict(model_clogit, bdendo_grid, type = "lp", se.fit = TRUE)
+bdendo_grid$fit <- inv_logit(bdendo_pred$fit)
+bdendo_grid$se <- inv_logit(bdendo_pred$se)
+bdendo_grid$lo <- inv_logit(bdendo_pred$fit - 1.96 * bdendo_pred$se)
+bdendo_grid$up <- inv_logit(bdendo_pred$fit + 1.96 * bdendo_pred$se)
 
 ## ------------------------------------------------------------------------
-xyplot(pred  ~ gall, data = bdendo_grid, groups = est, type = "l", 
-    lwd = 2, xlab = "Gall blader disease", ylab = "P (cancer)", 
-    auto.key = list(title = "Oestrogen", space = "right", cex = 0.8))
+xyplot(cbind(fit, lo, up) ~ gall|est, data = bdendo_grid,  pch = 20, 
+       panel = panel.errbars, xlab = "Gall blader disease", ylab = "P (cancer)")
 
 ## ------------------------------------------------------------------------
 library(ordinal, warn.conflicts = FALSE)
@@ -97,7 +100,7 @@ labs_ord <- c("Constant: Low/Medium satisfaction",
               "Accommodation: Atrium/Tower",
               "Accommodation: Terrace/Tower",
               "Afforded: High/Low")
-pander(glm_coef(model_clm, labels = labs_ord), split.table = Inf,
+kable(glm_coef(model_clm, labels = labs_ord), 
        caption = "Parameter estimates on satisfaction of householders.")
 
 ## ------------------------------------------------------------------------
@@ -116,7 +119,7 @@ glm_coef(model_multi)
 ## ------------------------------------------------------------------------
 plot(Effect(c("Infl", "Type", "Cont"), model_multi), main = NULL, aspect = 3/4, rotx = 45, 
      ylab = "Satisfaction (probability)", lines = list(lwd = 1.5, multiline = TRUE),
-     confint = list(style="none"), symbols = list(pch = rep(20, 3)),
+     confint = list(style = "none"), symbols = list(pch = rep(20, 3)),
      ylim = c(0, 1))
 
 ## ------------------------------------------------------------------------
@@ -127,7 +130,7 @@ model_pois <- glm(Days ~ Eth + Sex + Age, family = poisson, data = quine)
 glm_coef(model_pois)
 
 ## ------------------------------------------------------------------------
-pander(estat(~ Days|Eth, data = quine, label = "Days of school absences"), split.table=Inf)
+kable(estat(~ Days|Eth, data = quine, label = "Days of school absences"))
 
 ## ------------------------------------------------------------------------
 deviance(model_pois) / df.residual(model_pois)
@@ -142,21 +145,21 @@ unadj <- glm_coef(model_negbin, labels=c("Constant",
                                    "F3/Primary"))
 
 ## ------------------------------------------------------------------------
-pander(Anova(model_negbin))
+Anova(model_negbin)
 
 ## ------------------------------------------------------------------------
-pander(unadj, split.table = Inf, caption = "Parameter estimates with unadjusted CIs and p-values.")
+kable(unadj, caption = "Parameter estimates with unadjusted CIs and p-values.")
 
 ## ------------------------------------------------------------------------
 plot(Effect(c("Age", "Eth"), model_negbin), lines = list(lwd = 1.5, multiline = TRUE),
-     confint = list(style="none"), symbols = list(pch = rep(20, 2)), main = NULL, 
+     confint = list(style = "none"), symbols = list(pch = rep(20, 2)), main = NULL, 
      aspect = 3/4)
 
 ## ---- message=FALSE------------------------------------------------------
 model_glht <- glht(model_negbin, linfct  = mcp(Age = "Tukey"))
 age_glht <- xymultiple(model_glht, Exp = TRUE, plot = FALSE)
 
-## ---- fig.cap="Parameter estimates on the effect of age group on the number of days absent from school. Bars represent 95% CIs adjusted by the method of Westfall for multiple comparisons."----
+## ---- fig.cap="Parameter estimates on the effect of age group on the number of days absent from school. Bars represent 95% CIs adjusted by the method of Bonferroni for multiple comparisons."----
 xymultiple(model_glht, Exp = TRUE)
 
 ## ------------------------------------------------------------------------
@@ -166,9 +169,9 @@ age_glht[, 5] <- as.character(age_glht[, 5])
 final[4:6, 3:5] <- age_glht[1:3, 3:5]
 
 ## ------------------------------------------------------------------------
-pander(final, split.table = Inf, caption = "Parameter estimates. CIs and
+kable(final, caption = "Parameter estimates. CIs and
        p-values for age group were adjusted for multiple comparisons by the 
-       method of Westfall.")
+       method of Bonferroni")
 
 ## ------------------------------------------------------------------------
 data(bladder)
@@ -182,17 +185,14 @@ model_surv <- survreg(Surv(times, event) ~ rx, data = bladder)
 glm_coef(model_surv)
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_surv, labels = c("Treatment: Thiotepa/Placebo", "Scale")),
-       split.table = Inf)
+kable(glm_coef(model_surv, labels = c("Treatment: Thiotepa/Placebo", "Scale")))
 
 ## ------------------------------------------------------------------------
 model_exp <- survreg(Surv(times, event) ~ rx, data = bladder, dist = "exponential")
-pander(glm_coef(model_exp, labels = "Treatment: Thiotepa/Placebo"),
-       split.table = Inf)
+kable(glm_coef(model_exp, labels = "Treatment: Thiotepa/Placebo"))
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_exp, se.rob = FALSE, labels = "Treatment: Thiotepa/Placebo"),
-       split.table = Inf)
+kable(glm_coef(model_exp, se.rob = FALSE, labels = "Treatment: Thiotepa/Placebo"))
 
 ## ------------------------------------------------------------------------
 bladder_grid <- with(bladder, expand.grid(
@@ -214,7 +214,7 @@ xyplot(cbind(fit, lo, up) ~ rx, data = bladder_grid, pch = 20, panel = panel.err
 model_cox <-  coxph(Surv(times, event) ~ rx, data = bladder)
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_cox, labels = c("Treatment: Thiotepa/Placebo")), split.table = Inf)
+kable(glm_coef(model_cox, labels = c("Treatment: Thiotepa/Placebo")))
 
 ## ------------------------------------------------------------------------
 cox_grid <- with(bladder, expand.grid(
@@ -242,30 +242,8 @@ model_lme <- lme(distance ~ Sex * I(age - mean(age, na.rm = TRUE)), random = ~ 1
 glm_coef(model_lme)
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_lme, labels = c("Constant", "Sex: female-male", "Age (years)", 
-                                      "Sex:Age interaction")), split.table = Inf)
-
-## ---- warning=FALSE------------------------------------------------------
-plot(Effect(c("age", "Sex"), model_lme, residuals = TRUE), rug = FALSE, xlab = "Age (years)", 
-     ylab = "Distance (mm)", main = NULL, aspect = 3/4, partial.residuals = list(pch = 20),
-     lines = list(col = c(2, 4), lwd = 1.5))
-
-## ------------------------------------------------------------------------
-library(gee, warn.conflicts = FALSE)
-model_gee_norm <- gee(distance ~ Sex * I(age - mean(age, na.rm = TRUE)), id = Subject, 
-                      data = Orthodont, corstr = "AR-M")
-
-## ------------------------------------------------------------------------
-pander(glm_coef(model_gee_norm, labels = c("Constant", "Sex: female-male", "Age (years)", 
-                                      "Sex:Age interaction")), split.table = Inf)
-
-## ------------------------------------------------------------------------
-Orthodont$fit <- model_gee_norm$fitted.values
-
-## ------------------------------------------------------------------------
-xyplot(distance ~ age|Sex, data = Orthodont, groups = Subject, pch = 20, xlab = "Age (years)", 
-     ylab = "Distance (mm)", aspect = 3/4) +
-  xyplot(fit ~ age|Sex, data = Orthodont, type = "l", lwd = 2)
+kable(glm_coef(model_lme, labels = c("Constant", "Sex: female-male", "Age (years)", 
+                                      "Sex:Age interaction")))
 
 ## ------------------------------------------------------------------------
 data(Thall)
@@ -276,36 +254,16 @@ c3 <- cbind(Thall[, c(1:4, 7)], count = Thall$y3)[, c(1:4, 6)]
 c4 <- cbind(Thall[, c(1:4, 8)], count = Thall$y3)[, c(1:4, 6)]
 epilepsy <- rbind(c1, c2, c3, c4)
 
-## ----results = "hide"----------------------------------------------------
-model_gee <- gee(count ~ treat + base + I(age - mean(age, na.rm = TRUE)), id = factor(id), 
-                 data = epilepsy, family = poisson, corstr = "exchangeable", scale.fix = TRUE)
-
-## ------------------------------------------------------------------------
-pander(glm_coef(model_gee, labels = c("Constant", "Treatment (Prograbide/Control)", 
-                               "Baseline count", "Age (years)")), split.table = Inf)
-
 ## ----results = "hide"----------------------------------------------------
 library(lme4, warn.conflicts = FALSE)
 model_glmer <- glmer(count ~ treat + base + I(age - mean(age, na.rm = TRUE)) + 
                        (1|id), data=epilepsy, family=poisson)
 
 ## ------------------------------------------------------------------------
-pander(glm_coef(model_glmer, labels = c("Constant", "Treatment (Prograbide/Control)", 
-                               "Baseline count", "Age (years)")), split.table = Inf)
+kable(glm_coef(model_glmer, labels = c("Constant", "Treatment (Prograbide/Control)", 
+                               "Baseline count", "Age (years)")))
 
 ## ------------------------------------------------------------------------
 plot(Effect(c("age", "treat"), model_glmer), rug = FALSE, lwd = 2, main = NULL,
      xlab = "Age (years)", ylab = "Events", aspect = 3/4, multiline = TRUE)
 
-## ------------------------------------------------------------------------
-pander(estat(~ count|treat, data = epilepsy, label = "Number of seizures"))
-
-## ----results = "hide"----------------------------------------------------
-model_quasi <- gee(count ~ treat + base + I(age - mean(age, na.rm = TRUE)), id = factor(id), 
-                 data = epilepsy, family = quasi(variance = "mu^2", link = "log"), 
-                 corstr = "exchangeable")
-
-## ------------------------------------------------------------------------
-pander(glm_coef(model_quasi, labels = c("Constant", "Treatment (Prograbide/Control)", 
-                               "Baseline count", "Age (years)")), split.table = Inf)
-
